<?php
// Move session_start() to the top
session_start(); // Start session first

include '../database/server.php'; // Include database after session start

unset($_SESSION['login']);

if (isset($_GET['success'])) {
    $_SESSION['success'] = $_GET['success'];
}

if (isset($_POST['submit'])) {
    $username = trim($_POST['username']);
    $pass = $_POST['password'];

    $sql = "SELECT * FROM signup WHERE username = ?";
    $stmt = $conn->prepare($sql);
    $stmt->bind_param("s", $username);
    $stmt->execute();
    $result = $stmt->get_result();
    $stmt->close();

    if ($result->num_rows === 1) {
        $row = $result->fetch_assoc();
        $stored_hash = $row['password'];
        $country = $row['country'];
        $status = $row['status'];
        $_SESSION['phone'] = $row['phone'];

        if (password_verify($pass, $stored_hash)) {
            $_SESSION['login'] = $username;

            if ($status === 'active') {
                header("location: dashboard.php");
                exit();
            } else {
                if ($country === "Kenya") {
                    $_SESSION['error'] = "Inactive account. Redirecting to activation page.";
                    header("location: activate.php");
                    exit();
                } else {
                    $_SESSION['error'] = "Inactive account. Redirecting to activation page.";
                    header('location: https://eversend.me/realqash');
                    exit();
                }
            }
        } else {
            $_SESSION['error'] = "You entered an incorrect password.";
        }
    } else {
        $_SESSION['error'] = "Username does not exist in our records!";
    }
}
?>
<!DOCTYPE html>
<html lang="en">
<head>
    <meta charset="UTF-8">
    <meta name="viewport" content="width=device-width, initial-scale=1.0">
    <title>REALQASH</title>
    <link rel="stylesheet" href="https://cdnjs.cloudflare.com/ajax/libs/font-awesome/6.0.0-beta3/css/all.min.css">
    <style>
        /* General Styles */
        body {
            margin: 0;
            font-family: Arial, sans-serif;
             background: linear-gradient(135deg, #ff00ff, #d500d1);
            color: #fff;
            display: flex;
            justify-content: center;
            align-items: center;
            min-height: 100vh;
            padding: 20px;
        }
        .container {
            background: #fff;
            color: #FF00FF;
            max-width: 400px;
            width: 100%;
            padding: 20px;
            border-radius: 10px;
            box-shadow: 0 4px 8px rgba(0, 0, 0, 0.1);
        }
        .title h2 {
            text-align: center;
            margin-bottom: 20px;
            font-size: 1.8rem;
        }
        .input-control {
            margin-bottom: 15px;
        }
        .input-control label {
            display: block;
            margin-bottom: 5px;
            font-weight: bold;
        }
        .input-control input {
            width: 100%;
            padding: 10px;
            font-size: 1rem;
            border: 1px solid #ddd;
            border-radius: 5px;
        }
        .show-password {
            position: relative;
        }
        .show-password .icons {
            position: absolute;
            top: 50%;
            right: 10px;
            transform: translateY(-50%);
            cursor: pointer;
        }
        .button button {
            width: 100%;
            padding: 10px;
            font-size: 1rem;
            font-weight: bold;
            color: #fff;
            background: #0044cc;
            border: none;
            border-radius: 5px;
            cursor: pointer;
            transition: background 0.3s;
        }
        .button button:hover {
            background: #003399;
        }
        .remember-forgot {
            text-align: center;
            margin-top: 10px;
        }
        .remember-forgot a {
            color: #0044cc;
            text-decoration: none;
            font-weight: bold;
        }
        .remember-forgot a:hover {
            text-decoration: underline;
        }
        .alert {
            padding: 10px;
            margin-bottom: 15px;
            border-radius: 5px;
            font-size: 0.9rem;
            display: flex;
            justify-content: space-between;
            align-items: center;
        }
        .success-alert {
            background: #d4edda;
            color: #155724;
        }
        .error-alert {
            background: #FF0000;
            color: #FFFFFF;
        }
        .close-icon {
            cursor: pointer;
            font-size: 1.2rem;
        }

        /* Responsive Design */
        @media (max-width: 768px) {
            .container {
                padding: 15px;
            }
            .title h2 {
                font-size: 1.5rem;
            }
            .button button {
                font-size: 0.9rem;
            }
        }
    </style>
    <script>
        function showPassword() {
            const passInput = document.getElementById('pass');
            const showIcon = document.getElementById('show');
            const hideIcon = document.getElementById('hide');

            if (passInput.type === 'password') {
                passInput.type = 'text';
                showIcon.style.display = 'none';
                hideIcon.style.display = 'inline';
            } else {
                passInput.type = 'password';
                showIcon.style.display = 'inline';
                hideIcon.style.display = 'none';
            }
        }
    </script>
</head>
<body>
    <div class="container">
        <form method="POST">
            <?php
            if (isset($_SESSION['success'])) {
                echo "<div class='alert success-alert'><p><strong>Success!</strong> " . $_SESSION['success'] . "</p></div>";
                unset($_SESSION['success']);
            }
            if (isset($_SESSION['error'])) {
                echo "<div class='alert error-alert'><p><strong>Error!</strong> " . $_SESSION['error'] . "</p></div>";
                unset($_SESSION['error']);
            }
            ?>
            <div class="title">
                <h2>RealQash Login</h2>
            </div>
            <div class="input-control">
                <label for="user">Username</label>
                <input type="text" id="user" name="username" placeholder="Enter Username">
            </div>
            <div class="input-control">
                <label for="pass">Password</label>
                <div class="show-password">
                    <input type="password" id="pass" name="password" placeholder="Enter Password">
                    <div class="icons">
                        <i class="far fa-eye" id="show" onclick="showPassword()"></i>
                        <i class="far fa-eye-slash" id="hide" onclick="showPassword()" style="display:none;"></i>
                    </div>
                </div>
            </div>
            <div class="button">
                <button type="submit" name="submit">Login</button>
            </div>
            <div class="remember-forgot">
                <p>Don't have an account? <a href="register.php">Register</a></p>
                <p><a href="https://realqash.com/user/passwordreset.php">Forgot Password?</a></p>
            </div>
        </form>
    </div>
</body>
</html>
